@@ -7,9 +7,10 @@ from container_hub.models import (
     KubernetesBackendConfig,
     KubernetesJobConfig,
     KubernetesContainer,
+    NodeAffinityConfig,
 )
 from functools import cached_property
-
+from kubernetes.client.models import V1DeleteOptions
 
 from hikaru.model.rel_1_20 import (
     Job,
@@ -25,6 +26,12 @@ from hikaru.model.rel_1_20 import (
     VolumeMount,
     Volume,
     HostPathVolumeSource,
+    LocalObjectReference,
+    Affinity,
+    NodeAffinity,
+    NodeSelectorTerm,
+    NodeSelector,
+    NodeSelectorRequirement,
 )
 
 
@@ -75,7 +82,9 @@ class KubernetesBackend:
             api = BatchV1Api(api_client)
             job_list = None
             while job_list is None or job_list.metadata._continue is not None:
-                job_list: V1JobList = api.list_namespaced_job(namespace=self.config.namespace)
+                job_list: V1JobList = api.list_namespaced_job(
+                    namespace=self.config.namespace
+                )
                 jobs += [x for x in job_list.items]
         return [job.metadata.name.lstrip("simulation-") for job in jobs]
 
@@ -98,9 +107,30 @@ class KubernetesBackend:
                 name=name,
                 grace_period_seconds=0,
                 propagation_policy="Background",
+                body=V1DeleteOptions(propagation_policy='Background')
             )
 
 
+def get_node_affinity(node_affinity_cfg: NodeAffinityConfig) -> Affinity:
+    return Affinity(
+        nodeAffinity=NodeAffinity(
+            requiredDuringSchedulingIgnoredDuringExecution=NodeSelector(
+                nodeSelectorTerms=[
+                    NodeSelectorTerm(
+                        matchExpressions=[
+                            NodeSelectorRequirement(
+                                key=node_affinity_cfg.key,
+                                operator=node_affinity_cfg.operator,
+                                values=node_affinity_cfg.values,
+                            )
+                        ]
+                    )
+                ]
+            )
+        )
+    )
+
+
 def get_simulation_job(cfg: KubernetesJobConfig) -> Job:
     return Job(
         apiVersion="batch/v1",
@@ -117,7 +147,15 @@ def get_simulation_job(cfg: KubernetesJobConfig) -> Job:
                     labels={"app": cfg.name},
                 ),
                 spec=PodSpec(
+                    affinity=get_node_affinity(cfg.node_affinity)
+                    if cfg.node_affinity is not None
+                    else None,
                     serviceAccountName=cfg.service_account_name,
+                    imagePullSecrets=[
+                        LocalObjectReference(name=cfg.regcred_secret_name)
+                    ]
+                    if cfg.regcred_secret_name is not None
+                    else None,
                     hostAliases=[
                         HostAlias(x.ip_address, x.hostnames) for x in cfg.host_aliases
                     ],
