@@ -54,6 +54,7 @@ def test_loading_kubernetes_defaults(kubernetes_simple_settings):
             "labels": [],
             "mount_points": [],
             "ports": [6379],
+            "resources": None,
         },
         "scheduler_config": {
             "name": "scheduler",
@@ -79,6 +80,13 @@ def test_loading_kubernetes_defaults(kubernetes_simple_settings):
                     "read_only": False,
                 },
             ],
+            "resources": {
+                "limits": {
+                    "cpu": "1",
+                    "memory": "2Gi",
+                },
+                "requests": {"cpu": "250m", "memory": "128Mi"},
+            },
             "ports": [],
         },
         "scheduler_worker_config": {
@@ -111,6 +119,13 @@ def test_loading_kubernetes_defaults(kubernetes_simple_settings):
                     "read_only": False,
                 },
             ],
+            "resources": {
+                "limits": {
+                    "cpu": "1",
+                    "memory": "2Gi",
+                },
+                "requests": {"cpu": "250m", "memory": "128Mi"},
+            },
             "ports": [],
         },
         "simulation_config": {
@@ -131,9 +146,18 @@ def test_loading_kubernetes_defaults(kubernetes_simple_settings):
                     "read_only": False,
                 },
             ],
+            "resources": {
+                "limits": {
+                    "cpu": "1",
+                    "memory": "5Gi",
+                },
+                "requests": {"cpu": "1", "memory": "512Mi"},
+            },
             "ports": [],
         },
         "service_account_name": "simulation-service-account",
+        "regcred_secret_name": "regcred",
+        "node_affinity": {"key": "is_compute", "operator": "in", "values": ["true"]},
         "annotations": [],
         "labels": [],
     }
