@@ -29,6 +29,13 @@ CONTAINER_HUB_KUBERNETES_CONTAINER_DEFAULTS = {
             "/local/path/one": {"bind": "mount_path_1", "ro": True},
             "/local/path/two": {"bind": "mount_path_2", "ro": False},
         },
+        "resources": {
+            "limits": {
+                "cpu": "1",
+                "memory": "2Gi",
+            },
+            "requests": {"cpu": "250m", "memory": "128Mi"},
+        },
     },
     "SCHEDULER_WORKER": {
         "name": "scheduler_worker",
@@ -48,6 +55,13 @@ CONTAINER_HUB_KUBERNETES_CONTAINER_DEFAULTS = {
             "/local/path/one": {"bind": "mount_path_1", "ro": True},
             "/local/path/two": {"bind": "mount_path_2", "ro": False},
         },
+        "resources": {
+            "limits": {
+                "cpu": "1",
+                "memory": "2Gi",
+            },
+            "requests": {"cpu": "250m", "memory": "128Mi"},
+        },
     },
     "SIMULATION": {
         "name": "simulation",
@@ -58,5 +72,18 @@ CONTAINER_HUB_KUBERNETES_CONTAINER_DEFAULTS = {
             "/local/path/one": {"bind": "mount_path_1", "ro": True},
             "/local/path/two": {"bind": "mount_path_2", "ro": False},
         },
+        "resources": {
+            "limits": {
+                "cpu": "1",
+                "memory": "5Gi",
+            },
+            "requests": {"cpu": "1", "memory": "512Mi"},
+        },
+    },
+    "regcred_secret_name": "regcred",
+    "node_affinity": {
+        "key": "is_compute",
+        "operator": "in",
+        "values": ["true"],
     },
 }
